# Arizona Forum API Extended
Расширенная библиотека для Python, предоставляющая возможность взаимодействия с ресурсом forum.arizona-rp.com без необходимости в получении API ключа XenForo у администрации форума.

# Описание проекта
Данная библиотека является расширенным форком библиотеки [Arizona-API](https://github.com/TastyBread123/Arizona-API) от [TastyBread123](https://www.blast.hk/members/455219/)
Поддерживает около 38 методов, которые помогают в решении большого количества задач. API имеет удобные документации:
1. [Документация к текущей расширенной версии](https://github.com/fakelag28/Arizona-Forum-API-Extended/wiki/Основная-документация)
2. [Документация оригинальной библиотеки](https://tastybread123.github.io/Arizona-API/arz_api.html)
Также репозиторий имеет [примеры](https://github.com/fakelag28/Arizona-Forum-API-Extended/tree/main/examples), где показаны самые простые возможности использования библиотеки.

# Установка
Расширенная (текущая) версия доступна для установки при помощи PyPi:
```bash
pip install arizona-forum-api-extended
```
Оригинальный пакет доступен в PyPi:  
```bash
pip install arz-api
```